<?php

namespace Mmc\Music\Policies;

use Litepie\User\Contracts\UserPolicy;
use Mmc\Music\Models\Admin;

class AdminPolicy
{

    /**
     * Determine if the given user can view the admin.
     *
     * @param UserPolicy $user
     * @param Admin $admin
     *
     * @return bool
     */
    public function view(UserPolicy $user, Admin $admin)
    {
        if ($user->canDo('music.admin.view') && $user->isAdmin()) {
            return true;
        }

        return $admin->user_id == user_id() && $admin->user_type == user_type();
    }

    /**
     * Determine if the given user can create a admin.
     *
     * @param UserPolicy $user
     * @param Admin $admin
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('music.admin.create');
    }

    /**
     * Determine if the given user can update the given admin.
     *
     * @param UserPolicy $user
     * @param Admin $admin
     *
     * @return bool
     */
    public function update(UserPolicy $user, Admin $admin)
    {
        if ($user->canDo('music.admin.edit') && $user->isAdmin()) {
            return true;
        }

        return $admin->user_id == user_id() && $admin->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given admin.
     *
     * @param UserPolicy $user
     * @param Admin $admin
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Admin $admin)
    {
        return $admin->user_id == user_id() && $admin->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given admin.
     *
     * @param UserPolicy $user
     * @param Admin $admin
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Admin $admin)
    {
        if ($user->canDo('music.admin.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given admin.
     *
     * @param UserPolicy $user
     * @param Admin $admin
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Admin $admin)
    {
        if ($user->canDo('music.admin.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
