<?php

namespace Mmc\Music\Policies;

use Litepie\User\Contracts\UserPolicy;
use Mmc\Music\Models\Registration;

class RegistrationPolicy
{

    /**
     * Determine if the given user can view the registration.
     *
     * @param UserPolicy $user
     * @param Registration $registration
     *
     * @return bool
     */
    public function view(UserPolicy $user, Registration $registration)
    {
        if ($user->canDo('music.registration.view') && $user->isAdmin()) {
            return true;
        }

        return $registration->user_id == user_id() && $registration->user_type == user_type();
    }

    /**
     * Determine if the given user can create a registration.
     *
     * @param UserPolicy $user
     * @param Registration $registration
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('music.registration.create');
    }

    /**
     * Determine if the given user can update the given registration.
     *
     * @param UserPolicy $user
     * @param Registration $registration
     *
     * @return bool
     */
    public function update(UserPolicy $user, Registration $registration)
    {
        if ($user->canDo('music.registration.edit') && $user->isAdmin()) {
            return true;
        }

        return $registration->user_id == user_id() && $registration->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given registration.
     *
     * @param UserPolicy $user
     * @param Registration $registration
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Registration $registration)
    {
        return $registration->user_id == user_id() && $registration->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given registration.
     *
     * @param UserPolicy $user
     * @param Registration $registration
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Registration $registration)
    {
        if ($user->canDo('music.registration.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given registration.
     *
     * @param UserPolicy $user
     * @param Registration $registration
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Registration $registration)
    {
        if ($user->canDo('music.registration.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
