<?php

namespace Mmc\Music\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Mmc\Music\Models\Music;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Mmc\Music\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/music/admin/*')) {
            Route::bind('admin', function ($admin) {
                $adminrepo = $this->app->make('Mmc\Music\Interfaces\AdminRepositoryInterface');
                return $adminrepo->findorNew($admin);
            });
        }

        if (Request::is('*/music/form/*')) {
            Route::bind('form', function ($form) {
                $formrepo = $this->app->make('Mmc\Music\Interfaces\FormRepositoryInterface');
                return $formrepo->findorNew($form);
            });
        }

        if (Request::is('*/music/file/*')) {
            Route::bind('file', function ($file) {
                $filerepo = $this->app->make('Mmc\Music\Interfaces\FileRepositoryInterface');
                return $filerepo->findorNew($file);
            });
        }

        if (Request::is('*/music/registration/*')) {
            Route::bind('registration', function ($registration) {
                $registrationrepo = $this->app->make('Mmc\Music\Interfaces\RegistrationRepositoryInterface');
                return $registrationrepo->findorNew($registration);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        if(request()->segment(1) != 'api' && request()->segment(2) != 'api') {
            return;
        }

        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
